# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class LazyLoad(Component):
    """A LazyLoad component.
Wrapped from [react-lazyload](https://github.com/twobin/react-lazyload).
Lazyload your Components, Images or anything matters the performance.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Type: Node Default: undefined **NOTICE** Only one child is allowed
    to be passed.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- classNamePrefix (string; default 'lazyload'):
    Type: String Default: `lazyload` While rendering, Lazyload will
    add some elements to the component tree in addition to the wrapped
    *component children. The `classNamePrefix` prop allows the user to
    supply their own custom class prefix to help: # Avoid class
    conflicts on an implementing app # Allow easier custom styling
    These being: # A wrapper div, which is present at all times
    (default ).

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- debounce (number | boolean; optional):
    Type: Bool / Number Default: undefined Lazyload will try to use
    [passive event](https://github.com/WICG/EventListenerOptions/blob/
    gh-pages/*explainer.md) by default to improve scroll/resize event
    handler's performance. If you  prefer *control this behaviour by
    yourself, you can set `debounce` or `throttle` to enable built in
    delay *feature. If you provide a number, that will be how many
    `ms` to wait; if you provide `True`, the wait time  *defaults to
    `300ms`. **NOTICE** Set `debounce` / `throttle` to all lazy loaded
    components unanimously, if you don't,  the *first occurrence is
    respected.
    [demo](https://twobin.github.io/react-lazyload/examples/#/debounce).

- height (number | string; optional):
    Type: Number/String Default: undefined In the first round of
    render, LazyLoad will render a placeholder for your component if
    no  *placeholder is provided and measure if this component is
    visible. Set `height` properly will make  *LazyLoad calculate more
    precisely. The value can be number or string like `'100%'`. You
    can also  *use css to set the height of the placeholder instead of
    using `height`.

- offset (number | list; default 0):
    Type: Number/Array(Number) Default: 0 Say if you want to preload a
    component even if it's 100px below the viewport (user have to
    scroll  *100px more to see this component), you can set `offset`
    props to `100`. On the other hand, if you  *want to delay loading
    a component even if it's top edge has already appeared at
    viewport, set  *`offset` to negative number. Library supports
    horizontal lazy load out of the box. So when you provide this prop
    with number  *like `100` it will automatically set left edge
    offset to `100` and top edge to `100`; If you provide this prop
    with array like `[100, 200]`, it will set left edge offset to
    `100` and  *top offset to `200`.

- once (boolean; default False):
    Type: Bool Default: False Once the lazy loaded component is
    loaded, do not detect scroll/resize event anymore. Useful for
    *images or simple components.

- overflow (boolean; default False):
    Type: Bool Default: False If lazy loading components inside a
    overflow container, set this to `True`. Also make sure a
    *`position` property other than `static` has been set to your
    overflow container.
    [demo](https://twobin.github.io/react-lazyload/examples/#/overflow).

- placeholder (boolean | number | string | dict | list; optional):
    Type: Any Default: undefined Specify a placeholder for your lazy
    loaded component.
    [demo](https://twobin.github.io/react-lazyload/examples/#/placeholder)
    **If you provide your own placeholder, do remember add appropriate
    `height` or `minHeight` to your  *placeholder element for better
    lazyload performance.**.

- resize (boolean; default False):
    Type: Bool Default: False Respond to `resize` event, set it to
    `True` if you do need LazyLoad listen resize event. **NOTICE** If
    you tend to support legacy IE, set this props carefully, refer to
    [this question]*
    (http://stackoverflow.com/questions/1852751/window-resize-event-firing-in-internet-explorer)
    for  *further reading.

- scroll (boolean; default True):
    Type: Bool Default: True Listen and react to scroll event.

- scrollContainer (a list of or a singular dash component, string or number | string; optional):
    Type: String/DOM node Default: undefined Pass a query selector
    string or DOM node. LazyLoad will attach to the window object's
    scroll  events *if no container is passed.

- style (dict; optional):
    Type: Object Default: undefined Similar to
    [classNamePrefix](#classNamePrefix), the `style` prop allows users
    to pass custom CSS  *styles to wrapper div.

- throttle (number | boolean; optional):
    Type: Bool / Number Default: undefined Lazyload will try to use
    [passive event](https://github.com/WICG/EventListenerOptions/blob/
    gh-pages/*explainer.md) by default to improve scroll/resize event
    handler's performance. If you  prefer *control this behaviour by
    yourself, you can set `debounce` or `throttle` to enable built in
    delay *feature. If you provide a number, that will be how many
    `ms` to wait; if you provide `True`, the wait time  *defaults to
    `300ms`. **NOTICE** Set `debounce` / `throttle` to all lazy loaded
    components unanimously, if you don't,  the *first occurrence is
    respected.
    [demo](https://twobin.github.io/react-lazyload/examples/#/debounce).

- unmountIfInvisible (boolean; default False):
    Type: Bool Default: False The lazy loaded component is unmounted
    and replaced by the placeholder when it is no longer  visible *in
    the viewport."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, scrollContainer=Component.UNDEFINED, height=Component.UNDEFINED, once=Component.UNDEFINED, offset=Component.UNDEFINED, scroll=Component.UNDEFINED, resize=Component.UNDEFINED, overflow=Component.UNDEFINED, placeholder=Component.UNDEFINED, unmountIfInvisible=Component.UNDEFINED, debounce=Component.UNDEFINED, throttle=Component.UNDEFINED, classNamePrefix=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'classNamePrefix', 'class_name', 'debounce', 'height', 'offset', 'once', 'overflow', 'placeholder', 'resize', 'scroll', 'scrollContainer', 'style', 'throttle', 'unmountIfInvisible']
        self._type = 'LazyLoad'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'classNamePrefix', 'class_name', 'debounce', 'height', 'offset', 'once', 'overflow', 'placeholder', 'resize', 'scroll', 'scrollContainer', 'style', 'throttle', 'unmountIfInvisible']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(LazyLoad, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Textfit(Component):
    """A Textfit component.
Wrapped from [react-textfit](https://github.com/malte-wessel/react-textfit).

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    children.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- forceSingleModeWidth (boolean; optional):
    (Boolean) When mode is single and forceSingleModeWidth is True,
    the element's height will be ignored. Default is True.

- max (number; optional):
    (Number) Maximum font size in pixel. Default is 100.

- min (number; optional):
    (Number) Minimum font size in pixel. Default is 1.

- mode (string; optional):
    (single|multi) Algorithm to fit the text. Use single for headlines
    and multi for paragraphs. Default is multi.

- throttle (number; optional):
    (Number) Window resize throttle in milliseconds. Default is 50."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, mode=Component.UNDEFINED, forceSingleModeWidth=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, throttle=Component.UNDEFINED, onReady=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'forceSingleModeWidth', 'max', 'min', 'mode', 'throttle']
        self._type = 'Textfit'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'forceSingleModeWidth', 'max', 'min', 'mode', 'throttle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Textfit, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Weather(Component):
    """A Weather component.
Wrapped from [react-open-weather](https://github.com/farahat80/react-open-weather).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- api_key (string; required):
    your api key from the openweather, weatherbit or visual crossing
    websites.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- customData (dict; optional):
    Custom weather data. Refer to the format of the data obtained
    through the API.

- lang (string; default 'en'):
    the language to show \"humidity\" and \"wind speed\", feel free to
    open a PR to lang.js to add more languages \"en\", \"de\", \"es\".

- lat (number | string; default '48.137154'):
    latitude of the location.

- locationLabel (string; default 'Munich'):
    The name of the location or city to show in the component.

- lon (number | string; default '11.576124'):
    longitude of the location.

- option (string; default 'OpenWeather'):
    useOpenWeather, useWeatherBit and useVisualCrossing options.

- showForecast (boolean; default True):
    whether or not to show the forecast bottom part of the component.

- theme (dict; default {    fontFamily: 'Helvetica, sans-serif',    gradientStart: '#0181C2',    gradientMid: '#04A7F9',    gradientEnd: '#4BC4F7',    locationFontColor: '#FFF',    todayTempFontColor: '#FFF',    todayDateFontColor: '#B5DEF4',    todayRangeFontColor: '#B5DEF4',    todayDescFontColor: '#B5DEF4',    todayInfoFontColor: '#B5DEF4',    todayIconColor: '#FFF',    forecastBackgroundColor: '#FFF',    forecastSeparatorColor: '#DDD',    forecastDateColor: '#777',    forecastDescColor: '#777',    forecastRangeColor: '#777',    forecastIconColor: '#4BC4F7',}):
    Custom styling.

    `theme` is a dict with keys:

    - fontFamily (string; optional)

    - forecastBackgroundColor (string; optional)

    - forecastDateColor (string; optional)

    - forecastDescColor (string; optional)

    - forecastIconColor (string; optional)

    - forecastRangeColor (string; optional)

    - forecastSeparatorColor (string; optional)

    - gradientEnd (string; optional)

    - gradientMid (string; optional)

    - gradientStart (string; optional)

    - locationFontColor (string; optional)

    - todayDateFontColor (string; optional)

    - todayDescFontColor (string; optional)

    - todayIconColor (string; optional)

    - todayInfoFontColor (string; optional)

    - todayRangeFontColor (string; optional)

    - todayTempFontColor (string; optional)

- unit (string; default 'metric'):
    the unit will be passed to the openweather, weatherbit or
    visualcrossing \"units\" property, please check their
    documentation for more info.

- unitsLabels (dict; default {temperature: 'C', windSpeed: 'Km/h'}):
    the labels to be used for temprature and windspeed.

    `unitsLabels` is a dict with keys:

    - temperature (string; optional)

    - windSpeed (string; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, api_key=Component.REQUIRED, lat=Component.UNDEFINED, lon=Component.UNDEFINED, lang=Component.UNDEFINED, unit=Component.UNDEFINED, locationLabel=Component.UNDEFINED, unitsLabels=Component.UNDEFINED, showForecast=Component.UNDEFINED, option=Component.UNDEFINED, theme=Component.UNDEFINED, customData=Component.UNDEFINED, func=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'api_key', 'class_name', 'customData', 'lang', 'lat', 'locationLabel', 'lon', 'option', 'showForecast', 'theme', 'unit', 'unitsLabels']
        self._type = 'Weather'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'api_key', 'class_name', 'customData', 'lang', 'lat', 'locationLabel', 'lon', 'option', 'showForecast', 'theme', 'unit', 'unitsLabels']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['api_key']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Weather, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class QRCodeSVG(Component):
    """A QRCodeSVG component.
Wrapped from [qrcode.react](https://github.com/zpao/qrcode.react).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bgColor (string; optional):
    Background color. \"#FFFFFF\".

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- fgColor (string; optional):
    Foreground color. \"#000000\".

- imageSettings (dict; optional):
    Settings for pictures inserted in the QR code.

    `imageSettings` is a dict with keys:

    - excavate (boolean; optional):
        excavate.

    - height (number; optional):
        height of the img.

    - src (string; optional):
        The src of the image tag.

    - width (number; optional):
        width of the img.

    - x (number; optional):
        none, will center.

    - y (number; optional):
        none, will center.

- includeMargin (boolean; optional):
    Whether to include margins.

- level (string; optional):
    ('L' 'M' 'Q' 'H').

- size (number; optional):
    size.

- value (string; optional):
    The value of the QR code."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, value=Component.UNDEFINED, size=Component.UNDEFINED, bgColor=Component.UNDEFINED, fgColor=Component.UNDEFINED, level=Component.UNDEFINED, includeMargin=Component.UNDEFINED, imageSettings=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bgColor', 'class_name', 'fgColor', 'imageSettings', 'includeMargin', 'level', 'size', 'value']
        self._type = 'QRCodeSVG'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bgColor', 'class_name', 'fgColor', 'imageSettings', 'includeMargin', 'level', 'size', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(QRCodeSVG, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MouseParticles(Component):
    """A MouseParticles component.
Wrapped from [react-mouse-particles](https://github.com/lindelof/react-mouse-particles).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- alpha (number; default 0.1):
    The alpha of every particle.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string | list of strings; default 'random'):
    Particle color.

- cull (string; optional):
    Eliminate dom's className without triggering animation.

- g (number; default 1):
    Whether to add gravity.

- level (number; default 6):
    Detect levels of culling animation.

- life (number; default 1.2):
    The life of every particle.

- num (number; default 3):
    The number of particles emitted each time.

- radius (number; default 10):
    The radius of every particle.

- tha (number; default 20):
    The Particle emitter angle.

- v (number; default 0.5):
    The Particle emitter Particle velocity."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, g=Component.UNDEFINED, num=Component.UNDEFINED, radius=Component.UNDEFINED, alpha=Component.UNDEFINED, tha=Component.UNDEFINED, v=Component.UNDEFINED, life=Component.UNDEFINED, color=Component.UNDEFINED, cull=Component.UNDEFINED, level=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'alpha', 'class_name', 'color', 'cull', 'g', 'level', 'life', 'num', 'radius', 'tha', 'v']
        self._type = 'MouseParticles'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'alpha', 'class_name', 'color', 'cull', 'g', 'level', 'life', 'num', 'radius', 'tha', 'v']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(MouseParticles, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Barcode(Component):
    """A Barcode component.
Wrapped from [react-barcode](https://github.com/kciter/react-barcode).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- background (string; default '#ffffff'):
    Set the background of the barcode.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- displayValue (boolean; default True):
    Whether to display the barcode value.

- flat (string; optional):
    Only for EAN8/EAN13.

- font (string; default 'monospace'):
    Define the font used for the text in the generated barcode. This
    can be any default font or a font defined by a @font-face rule.

- fontOptions (string; default ''):
    With fontOptions you can add bold or italic text to the barcode.

- fontSize (number; default 20):
    Set the size of the text.

- format (string; default 'CODE128'):
    Select which barcode type to use. Please check the wikipage of the
    different barcode types for more information.

- height (number; default 100):
    The height of the barcode.

- lineColor (string; default '#000000'):
    Set the color of the bars and the text.

- margin (number; default 10):
    Set the space margin around the barcode. If nothing else is set,
    all side will inherit the margins property but can be replaced if
    you want to set them separably.

- marginBottom (number; optional):
    margins.

- marginLeft (number; optional):
    margins.

- marginRight (number; optional):
    margins.

- marginTop (number; optional):
    margins.

- text (string; optional):
    Overide the text that is diplayed.

- textAlign (string; default 'center'):
    Set the horizontal alignment of the text. Can be left / center /
    right.

- textMargin (number; default 2):
    Set the space between the barcode and the text.

- textPosition (string; default 'bottom'):
    Set the vertical position of the text. Can be bottom / top.

- value (string | number; optional):
    The value of the barcode.

- width (number; default 2):
    The width option is the width of a single bar."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, value=Component.UNDEFINED, width=Component.UNDEFINED, height=Component.UNDEFINED, format=Component.UNDEFINED, displayValue=Component.UNDEFINED, text=Component.UNDEFINED, fontOptions=Component.UNDEFINED, font=Component.UNDEFINED, textAlign=Component.UNDEFINED, textPosition=Component.UNDEFINED, textMargin=Component.UNDEFINED, fontSize=Component.UNDEFINED, background=Component.UNDEFINED, lineColor=Component.UNDEFINED, margin=Component.UNDEFINED, marginTop=Component.UNDEFINED, marginBottom=Component.UNDEFINED, marginLeft=Component.UNDEFINED, marginRight=Component.UNDEFINED, flat=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'background', 'class_name', 'displayValue', 'flat', 'font', 'fontOptions', 'fontSize', 'format', 'height', 'lineColor', 'margin', 'marginBottom', 'marginLeft', 'marginRight', 'marginTop', 'text', 'textAlign', 'textMargin', 'textPosition', 'value', 'width']
        self._type = 'Barcode'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'background', 'class_name', 'displayValue', 'flat', 'font', 'fontOptions', 'fontSize', 'format', 'height', 'lineColor', 'margin', 'marginBottom', 'marginLeft', 'marginRight', 'marginTop', 'text', 'textAlign', 'textMargin', 'textPosition', 'value', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Barcode, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ParticlesBg(Component):
    """A ParticlesBg component.
Wrapped from [particles-bg](https://github.com/lindelof/particles-bg).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bg (boolean | dict | string; default True):
    Eliminate dom's className without triggering animation.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string | list of strings; default 'random'):
    The background color or particle color of the particle scene.

- config (dict; optional):
    You can use type=\"custom\" to achieve a higher degree of freedom
    for the particle background.

    `config` is a dict with keys:

    - alpha (number | list; optional)

    - body (string; optional)

    - color (string | list of strings; optional)

    - cross (string; optional)

    - f (number | list; optional)

    - func (optional)

    - g (number; optional)

    - life (number | list; optional)

    - num (number | list; optional)

    - position (string; optional)

    - radius (number | list; optional)

    - random (number | boolean; optional)

    - rotate (number | list; optional)

    - rps (number; optional)

    - scale (number | list; optional)

    - tha (number | list; optional)

    - v (number | list; optional)

- num (number; optional):
    The number of particles emitted each time, generally not set.

- type (string; default 'random'):
    The type of particle animation. \"color\", \"ball\", \"lines\",
    \"thick\", \"circle\", \"cobweb\" ,\"polygon\", \"square\",
    \"tadpole\", \"fountain\", \"random\", \"custom\"."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, type=Component.UNDEFINED, num=Component.UNDEFINED, color=Component.UNDEFINED, bg=Component.UNDEFINED, config=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bg', 'class_name', 'color', 'config', 'num', 'type']
        self._type = 'ParticlesBg'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bg', 'class_name', 'color', 'config', 'num', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ParticlesBg, self).__init__(**args)



from .Barcode import Barcode
from .Clock import Clock
from .Snake import Snake
from .LazyLoad import LazyLoad
from .Masonry import Masonry
from .MouseParticles import MouseParticles
from .ParticlesBg import ParticlesBg
from .PowerModeInput import PowerModeInput
from .QRCodeCanvas import QRCodeCanvas
from .QRCodeSVG import QRCodeSVG
from .Textfit import Textfit
from .Weather import Weather

__all__ = [
    "Barcode",
    "Clock",
    "Snake",
    "LazyLoad",
    "Masonry",
    "MouseParticles",
    "ParticlesBg",
    "PowerModeInput",
    "QRCodeCanvas",
    "QRCodeSVG",
    "Textfit",
    "Weather"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PowerModeInput(Component):
    """A PowerModeInput component.
Wrapped from [power-mode-input](https://github.com/lindelof/power-mode-input).

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- config (dict; default {    height: 5,    tha: [0, 360],    g: 0.5,    num: 5,    radius: 6,    circle: True,    alpha: [0.75, 0.1],    color: 'random',}):
    You can use type=\"custom\" to achieve a higher degree of freedom
    for the particle background.

    `config` is a dict with keys:

    - alpha (number | list; optional)

    - circle (boolean; optional)

    - color (string | list of strings; optional)

    - g (number; optional)

    - height (number; optional)

    - num (number | list; optional)

    - radius (number | list; optional)

    - tha (number | list; optional)

- defaultValue (boolean | number | string | dict | list; optional):
    Default value of the input tag.

- maxLength (number; default 128):
    The length limit of the input.

- placeholder (string; optional):
    Placeholder of the input tag.

- style (dict; optional):
    Style of the input tag.

- type (string; default 'text'):
    Type of the input tag.

- value (boolean | number | string | dict | list; optional):
    Value of the input tag."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, type=Component.UNDEFINED, placeholder=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, maxLength=Component.UNDEFINED, style=Component.UNDEFINED, config=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'class_name', 'config', 'defaultValue', 'maxLength', 'placeholder', 'style', 'type', 'value']
        self._type = 'PowerModeInput'
        self._namespace = 'dash_grocery'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'class_name', 'config', 'defaultValue', 'maxLength', 'placeholder', 'style', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PowerModeInput, self).__init__(**args)
